searchData={"items":[{"type":"module","title":"CozySVG","doc":"A tiny and fast library to compile and render SVG files.\n\n`CozySVG` reads the SVG files at compile-time and provides runtime access\nthrough a term stored in the BEAM file, which is very fast to access.","ref":"CozySVG.html"},{"type":"module","title":"Why use it? - CozySVG","doc":"It is recommended to embed the SVG data into web pages instead of asking\nthe browser to make additional requests to servers. This makes web pages load\nfaster.\n\n`CozySVG` provides the key ability to do this - reading the SVG files as\nstrings in an efficient way. That's the key.","ref":"CozySVG.html#module-why-use-it"},{"type":"module","title":"Usage - CozySVG","doc":"To use `CozySVG`, it's better to create a wrapper module instead of calling\nthe low-level API directly.\n\n#","ref":"CozySVG.html#module-usage"},{"type":"module","title":"create wrapper module with pre-built macro - CozySVG","doc":"See `CozySVG.QuickWrapper` for more details.\n\n#","ref":"CozySVG.html#module-create-wrapper-module-with-pre-built-macro"},{"type":"module","title":"create wrapper module with low-level API - CozySVG","doc":"This method offers the greatest flexibility, allowing you to customize naming\n, rendering or compiling as required.\n\nAn example:\n\n    defmodule DemoWeb.SVG do\n      # Build the library at compile time\n      @library CozySVG.compile(\"assets/svg\")\n\n      # Accesses the library at runtime\n      defp library(), do: @library\n\n      # Render an SVG from the library\n      def render(key, attrs \\ []) do\n        CozySVG.render(library(), key, attrs)\n      end\n\n      # Render an SVG from the library\n      def render!(key, attrs \\ []) do\n        CozySVG.render!(library(), key, attrs)\n      end\n    end\n\n`DemoWeb.SVG.render/1` / `DemoWeb.SVG.render/2` / `DemoWeb.SVG.render!/1` / `DemoWeb.SVG.render!/2`\nwill be ready to use.\n\n> #### `@library` should be accessed through a function. {: .info}\n>\n> The library could be very large, wrapping it with a function ensures that \n> it is only stored as a term in BEAM file once.\n\n#","ref":"CozySVG.html#module-create-wrapper-module-with-low-level-api"},{"type":"module","title":"The requirements for SVG files - CozySVG","doc":"Every SVG file must contain a single valid `  ` tag.\n\nAnything before the ` ` tag or after the ` ` tag is treated as\ncomment and stripped from the content during compilation.","ref":"CozySVG.html#module-the-requirements-for-svg-files"},{"type":"module","title":"Phoenix Integration - CozySVG","doc":"### `svg/1` component\n\nAn example module:\n      \n    defmodule DemoWebSvgComponents do\n      defmodule CompiledSVG do\n        use CozySVG.QuickWrapper, root: \"assets/svg\"\n      end\n    \n      use Phoenix.Component\n      import Phoenix.HTML, only: [raw: 1]\n    \n      attr :key, :string, required: true, doc: \"The key for SVG file.\"\n      attr :rest, :global, doc: \"Additional attributes to add to the   tag.\"\n    \n      def svg(assigns) do\n        ~H\"\"\"\n        <%= raw(CompiledSVG.render!(@key, @rest)) %>\n        \"\"\"\n      end\n    end\n\n#","ref":"CozySVG.html#module-phoenix-integration"},{"type":"module","title":"Live reloading - CozySVG","doc":"Enable live reloading by telling Phoenix to watch the SVG directory:\n\n    live_reload: [\n      patterns: [\n        # ...\n        ~r\"assets/svg/*/.*(svg)$\"\n      ]\n    ]","ref":"CozySVG.html#module-live-reloading"},{"type":"function","title":"CozySVG.compile/2","doc":"Compiles a folder of `*.svg` files into a library.\n\nThe folder and it's subfolders will be traversed and all valid `*.svg` files\nwill be added to the library with a key that is relative path of the SVG file\nminus the `.svg` part.\n\nFor example, if you compile the folder `\"assets/svg\"` and it finds a file with\nthe path `\"assets/svg/heroicons/calendar.svg\"`, then the key for that SVG is\n`\"heroicons/calendar\"` in the library.","ref":"CozySVG.html#compile/2"},{"type":"function","title":"Examples - CozySVG.compile/2","doc":"# Compiles a folder\n    CozySVG.compile(\"assets/svg\")\n\n    # Compiles multiple folders\n    CozySVG.compile(\"assets/svg_a\")\n    |> CozySVG.compile(\"assets/svg_b\")\n\n    # Or, compiles multiple folders with a neater pipeline\n    %{}\n    |> CozySVG.compile(\"assets/svg_a\")\n    |> CozySVG.compile(\"assets/svg_b\")","ref":"CozySVG.html#compile/2-examples"},{"type":"function","title":"CozySVG.render/2","doc":"Renders an SVG as a string.\n\nThe named svg must be in the provided library, which should be built using the\ncompile function.","ref":"CozySVG.html#render/2"},{"type":"function","title":"Examples - CozySVG.render/2","doc":"iex> CozySVG.render(library(), \"heroicons/menu\")\n    {:ok, \" \"}","ref":"CozySVG.html#render/2-examples"},{"type":"function","title":"CozySVG.render/3","doc":"Renders an SVG as a string.\n\nThe named svg must be in the provided library, which should be built using the\ncompile function.\n\nThe `attrs` will be inserted as attributes of the `  ` tag. But keep\none thing in mind, the underscore character `\"_\"` in attribute name will be\nconverted to the hyphen character `\"-\"`.","ref":"CozySVG.html#render/3"},{"type":"function","title":"Examples - CozySVG.render/3","doc":"iex> CozySVG.render(library(), \"heroicons/menu\", class: \"h-5 w-5\")\n    {:ok, \" \"}\n\n    iex> CozySVG.render(library(), \"heroicons/menu\", %{phx_click: \"action\"})\n    {:ok, \" \"}","ref":"CozySVG.html#render/3-examples"},{"type":"function","title":"CozySVG.render!/2","doc":"The bang variant of `render/2`.","ref":"CozySVG.html#render!/2"},{"type":"function","title":"Examples - CozySVG.render!/2","doc":"iex> CozySVG.render!(library(), \"heroicons/menu\")\n    \" \"","ref":"CozySVG.html#render!/2-examples"},{"type":"function","title":"CozySVG.render!/3","doc":"The bang variant of `render/3`.","ref":"CozySVG.html#render!/3"},{"type":"function","title":"Examples - CozySVG.render!/3","doc":"iex> CozySVG.render!(library(), \"heroicons/menu\", class: \"h-5 w-5\")\n    \" \"\n\n    iex> CozySVG.render!(library(), \"heroicons/menu\", %{phx_click: \"action\"})\n    \" \"","ref":"CozySVG.html#render!/3-examples"},{"type":"type","title":"CozySVG.attrs/0","doc":"","ref":"CozySVG.html#t:attrs/0"},{"type":"type","title":"CozySVG.key/0","doc":"","ref":"CozySVG.html#t:key/0"},{"type":"type","title":"CozySVG.library/0","doc":"","ref":"CozySVG.html#t:library/0"},{"type":"type","title":"CozySVG.path/0","doc":"","ref":"CozySVG.html#t:path/0"},{"type":"module","title":"CozySVG.QuickWrapper","doc":"Creates a wrapper module quickly.\n\n> This is a high-level abstraction of the basic API provided by `CozySVG`.","ref":"CozySVG.QuickWrapper.html"},{"type":"module","title":"Usage - CozySVG.QuickWrapper","doc":"Assuming the structure of SVG files is like this:\n\n    assets/svg\n    ├── logo.svg\n    └── misc\n        ├── header.svg\n        └── footer.svg\n\nCreates a wrapper module:\n\n    defmodule DemoWeb.SVG do\n      use CozySVG.QuickWrapper, root: \"assets/svg\"\n    end\n\nThen, the generated functions can be used like this:\n\n    DemoWeb.SVG.render(\"logo\")\n    DemoWeb.SVG.render(\"misc/header\", class: \"w-6 h-auto mr-2\")\n    DemoWeb.SVG.render(\"misc/footer\", class: \"w-6 h-auto mr-2\")\n\n    DemoWeb.SVG.render!(\"logo\")\n    DemoWeb.SVG.render!(\"misc/header\", class: \"w-6 h-auto mr-2\")\n    DemoWeb.SVG.render!(\"misc/footer\", class: \"w-6 h-auto mr-2\")","ref":"CozySVG.QuickWrapper.html#module-usage"},{"type":"exception","title":"CozySVG.CompileError","doc":"","ref":"CozySVG.CompileError.html"},{"type":"type","title":"CozySVG.CompileError.t/0","doc":"","ref":"CozySVG.CompileError.html#t:t/0"},{"type":"exception","title":"CozySVG.RuntimeError","doc":"","ref":"CozySVG.RuntimeError.html"},{"type":"type","title":"CozySVG.RuntimeError.t/0","doc":"","ref":"CozySVG.RuntimeError.html#t:t/0"},{"type":"extras","title":"CozySVG","doc":"# CozySVG\n\n[![CI](https://github.com/cozy-elixir/cozy_svg/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/cozy_svg/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/cozy_svg.svg)](https://hex.pm/packages/cozy_svg)\n[![built with Nix](https://img.shields.io/badge/built%20with%20Nix-5277C3?logo=nixos&logoColor=white)](https://builtwithnix.org)\n\n> A tiny and fast library to compile and render SVG files.","ref":"readme.html"},{"type":"extras","title":"Installation - CozySVG","doc":"Add `:cozy_svg` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cozy_svg,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CozySVG","doc":"For more information, see the [documentation](https://hexdocs.pm/cozy_svg).","ref":"readme.html#usage"},{"type":"extras","title":"License - CozySVG","doc":"Apache License 2.0","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"Breaking changes:\n\n- `CozySVG.render` is renamed to `CozySVG.render!`\n\nEnhancements:\n\n- add non-raising version render function - `CozySVG.render`","ref":"changelog.html#v0-2-0"}],"content_type":"text/markdown"}